mailr13072 - in /branches/gui_testing/gui: ./ user_functions/


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on June 16, 2011 - 17:01:
Author: bugman
Date: Thu Jun 16 17:01:30 2011
New Revision: 13072

URL: http://svn.gna.org/viewcvs/relax?rev=13072&view=rev
Log:
Removed all remnants of user functions from the Wiz_window class.

This includes renaming the add_uf() method to add_contents().


Modified:
    branches/gui_testing/gui/user_functions/molecule.py
    branches/gui_testing/gui/user_functions/pipes.py
    branches/gui_testing/gui/user_functions/relax_data.py
    branches/gui_testing/gui/user_functions/residue.py
    branches/gui_testing/gui/user_functions/sequence.py
    branches/gui_testing/gui/user_functions/spin.py
    branches/gui_testing/gui/user_functions/value.py
    branches/gui_testing/gui/wizard.py

Modified: branches/gui_testing/gui/user_functions/molecule.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/gui_testing/gui/user_functions/molecule.py?rev=13072&r1=13071&r2=13072&view=diff
==============================================================================
--- branches/gui_testing/gui/user_functions/molecule.py (original)
+++ branches/gui_testing/gui/user_functions/molecule.py Thu Jun 16 17:01:30 
2011
@@ -107,7 +107,7 @@
     title = 'Addition of new molecules'
 
 
-    def add_uf(self, sizer):
+    def add_contents(self, sizer):
         """Add the molecule specific GUI elements.
 
         @param sizer:   A sizer object.
@@ -145,7 +145,7 @@
     title = 'Molecule copy'
 
 
-    def add_uf(self, sizer):
+    def add_contents(self, sizer):
         """Add the molecule specific GUI elements.
 
         @param sizer:   A sizer object.
@@ -238,7 +238,7 @@
     title = 'Molecule deletion'
 
 
-    def add_uf(self, sizer):
+    def add_contents(self, sizer):
         """Add the molecule specific GUI elements.
 
         @param sizer:   A sizer object.

Modified: branches/gui_testing/gui/user_functions/pipes.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/gui_testing/gui/user_functions/pipes.py?rev=13072&r1=13071&r2=13072&view=diff
==============================================================================
--- branches/gui_testing/gui/user_functions/pipes.py (original)
+++ branches/gui_testing/gui/user_functions/pipes.py Thu Jun 16 17:01:30 2011
@@ -121,7 +121,7 @@
     title = 'Addition of new data pipes'
 
 
-    def add_uf(self, sizer):
+    def add_contents(self, sizer):
         """Add the pipe specific GUI elements.
 
         @param sizer:   A sizer object.
@@ -159,7 +159,7 @@
     title = 'Data pipe copy'
 
 
-    def add_uf(self, sizer):
+    def add_contents(self, sizer):
         """Add the pipe specific GUI elements.
 
         @param sizer:   A sizer object.
@@ -218,7 +218,7 @@
     title = 'Data pipe deletion'
 
 
-    def add_uf(self, sizer):
+    def add_contents(self, sizer):
         """Add the pipe specific GUI elements.
 
         @param sizer:   A sizer object.
@@ -274,7 +274,7 @@
     title = 'Switch between data pipes'
 
 
-    def add_uf(self, sizer):
+    def add_contents(self, sizer):
         """Add the pipe specific GUI elements.
 
         @param sizer:   A sizer object.

Modified: branches/gui_testing/gui/user_functions/relax_data.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/gui_testing/gui/user_functions/relax_data.py?rev=13072&r1=13071&r2=13072&view=diff
==============================================================================
--- branches/gui_testing/gui/user_functions/relax_data.py (original)
+++ branches/gui_testing/gui/user_functions/relax_data.py Thu Jun 16 17:01:30 
2011
@@ -88,7 +88,7 @@
     title = 'Relaxation data deletion'
 
 
-    def add_uf(self, sizer):
+    def add_contents(self, sizer):
         """Add the relaxation data deletion specific GUI elements.
 
         @param sizer:   A sizer object.
@@ -148,7 +148,7 @@
     title = 'Relaxation data reading'
 
 
-    def add_uf(self, sizer):
+    def add_contents(self, sizer):
         """Add the relaxation data reading specific GUI elements.
 
         @param sizer:   A sizer object.

Modified: branches/gui_testing/gui/user_functions/residue.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/gui_testing/gui/user_functions/residue.py?rev=13072&r1=13071&r2=13072&view=diff
==============================================================================
--- branches/gui_testing/gui/user_functions/residue.py (original)
+++ branches/gui_testing/gui/user_functions/residue.py Thu Jun 16 17:01:30 
2011
@@ -123,7 +123,7 @@
     title = 'Residue copy'
 
 
-    def add_uf(self, sizer):
+    def add_contents(self, sizer):
         """Add the residue specific GUI elements.
 
         @param sizer:   A sizer object.
@@ -255,7 +255,7 @@
     title = 'Addition of new residues'
 
 
-    def add_uf(self, sizer):
+    def add_contents(self, sizer):
         """Add the residue specific GUI elements.
 
         @param sizer:   A sizer object.
@@ -324,7 +324,7 @@
     main_text = 'This dialog allows you to delete residues from the relax 
data store.  The residue will be deleted from the current data pipe.'
     title = 'Residue deletion'
 
-    def add_uf(self, sizer):
+    def add_contents(self, sizer):
         """Add the residue specific GUI elements.
 
         @param sizer:   A sizer object.

Modified: branches/gui_testing/gui/user_functions/sequence.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/gui_testing/gui/user_functions/sequence.py?rev=13072&r1=13071&r2=13072&view=diff
==============================================================================
--- branches/gui_testing/gui/user_functions/sequence.py (original)
+++ branches/gui_testing/gui/user_functions/sequence.py Thu Jun 16 17:01:30 
2011
@@ -71,7 +71,7 @@
     title = 'Sequence reading'
 
 
-    def add_uf(self, sizer):
+    def add_contents(self, sizer):
         """Add the sequence specific GUI elements.
 
         @param sizer:   A sizer object.

Modified: branches/gui_testing/gui/user_functions/spin.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/gui_testing/gui/user_functions/spin.py?rev=13072&r1=13071&r2=13072&view=diff
==============================================================================
--- branches/gui_testing/gui/user_functions/spin.py (original)
+++ branches/gui_testing/gui/user_functions/spin.py Thu Jun 16 17:01:30 2011
@@ -139,7 +139,7 @@
     title = 'Spin copy'
 
 
-    def add_uf(self, sizer):
+    def add_contents(self, sizer):
         """Add the spin specific GUI elements.
 
         @param sizer:   A sizer object.
@@ -302,7 +302,7 @@
     main_text = 'This dialog allows you to add new spins to the relax data 
store.  The spin will be added to the current data pipe.'
     title = 'Addition of new spins'
 
-    def add_uf(self, sizer):
+    def add_contents(self, sizer):
         """Add the spin specific GUI elements.
 
         @param sizer:   A sizer object.
@@ -377,7 +377,7 @@
     title = 'Spin deletion'
 
 
-    def add_uf(self, sizer):
+    def add_contents(self, sizer):
         """Add the spin specific GUI elements.
 
         @param sizer:   A sizer object.

Modified: branches/gui_testing/gui/user_functions/value.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/gui_testing/gui/user_functions/value.py?rev=13072&r1=13071&r2=13072&view=diff
==============================================================================
--- branches/gui_testing/gui/user_functions/value.py (original)
+++ branches/gui_testing/gui/user_functions/value.py Thu Jun 16 17:01:30 2011
@@ -67,7 +67,7 @@
     title = 'Value setting'
 
 
-    def add_uf(self, sizer):
+    def add_contents(self, sizer):
         """Add the sequence specific GUI elements.
 
         @param sizer:   A sizer object.

Modified: branches/gui_testing/gui/wizard.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/gui_testing/gui/wizard.py?rev=13072&r1=13071&r2=13072&view=diff
==============================================================================
--- branches/gui_testing/gui/wizard.py (original)
+++ branches/gui_testing/gui/wizard.py Thu Jun 16 17:01:30 2011
@@ -21,7 +21,7 @@
 
###############################################################################
 
 # Module docstring.
-"""Base class module for the user function GUI elements."""
+"""Base class module for the wizard GUI elements."""
 
 # Python module imports.
 import wx
@@ -60,7 +60,7 @@
 
 
     def select(self, event):
-        """The script user function GUI element.
+        """The file selector GUI element.
 
         @param event:   The wx event.
         @type event:    wx event
@@ -82,9 +82,9 @@
 
 
 class Wiz_window(wx.Dialog):
-    """User function window GUI element base class.
-
-    To inherit from this class, you must supply the add_uf() and execute() 
methods.  The add_uf() method should build the GUI elements specific to the 
user function, which the execute() method runs the user function.
+    """Wizard-like window GUI element base class.
+
+    To inherit from this class, you must supply the add_contents() and 
execute() methods.  The add_contents() method should build the specific GUI 
elements, and the execute() method is called when clicking on the apply or ok 
buttons.
     """
 
     # Some class variables.
@@ -103,7 +103,7 @@
     title = ''
 
     def __init__(self, gui, interpreter, style=wx.DEFAULT_DIALOG_STYLE):
-        """Set up the user function class."""
+        """Set up the window."""
 
         # Store the args.
         self.gui = gui
@@ -144,9 +144,9 @@
         # Add the description.
         self.add_desc(main_sizer)
 
-        # Add the user function specific GUI elements (bounded by spacers).
+        # Add the specific GUI elements (bounded by spacers).
         main_sizer.AddStretchSpacer()
-        self.add_uf(main_sizer)
+        self.add_contents(main_sizer)
         main_sizer.AddStretchSpacer()
         main_sizer.AddStretchSpacer()
 
@@ -187,7 +187,7 @@
         if self.button_apply:
             button = buttons.ThemedGenBitmapTextButton(self, -1, None, 
"Apply")
             button.SetBitmapLabel(wx.Bitmap(paths.icon_22x22.apply, 
wx.BITMAP_TYPE_ANY))
-            button.SetToolTipString("Apply the user function")
+            button.SetToolTipString("Apply the operation")
             button_sizer.Add(button, 0, wx.ADJUST_MINSIZE, 0)
             self.Bind(wx.EVT_BUTTON, self.apply, button)
 
@@ -198,7 +198,7 @@
         if self.button_ok:
             button = buttons.ThemedGenBitmapTextButton(self, -1, None, "OK")
             button.SetBitmapLabel(wx.Bitmap(paths.icon_22x22.ok, 
wx.BITMAP_TYPE_ANY))
-            button.SetToolTipString("Accept the user function")
+            button.SetToolTipString("Accept the operation")
             button_sizer.Add(button, 0, wx.ADJUST_MINSIZE, 0)
             self.Bind(wx.EVT_BUTTON, self.ok, button)
 
@@ -209,7 +209,7 @@
         if self.button_cancel:
             button = buttons.ThemedGenBitmapTextButton(self, -1, None, 
"Cancel")
             button.SetBitmapLabel(wx.Bitmap(paths.icon_22x22.cancel, 
wx.BITMAP_TYPE_ANY))
-            button.SetToolTipString("Abort the user function")
+            button.SetToolTipString("Abort the operation")
             button_sizer.Add(button, 0, wx.ADJUST_MINSIZE, 0)
             self.Bind(wx.EVT_BUTTON, self.cancel, button)
 
@@ -267,8 +267,8 @@
         sizer.AddSpacer(10)
 
 
-    def add_uf(self, sizer):
-        """Add the user function specific GUI elements (dummy method).
+    def add_contents(self, sizer):
+        """Add the specific GUI elements (dummy method).
 
         @param sizer:   A sizer object.
         @type sizer:    wx.Sizer instance
@@ -278,13 +278,13 @@
 
 
     def apply(self, event):
         """Apply the user function.
 
         @param event:   The wx event.
         @type event:    wx event
         """
 
-        # Execute the user function.
+        # Execute.
         try:
             self.execute()
         except AllRelaxErrors, instance:
@@ -330,7 +330,7 @@
 
 
     def cancel(self, event):
         """Cancel the user function.
 
         @param event:   The wx event.
         @type event:    wx event
@@ -450,7 +450,7 @@
 
 
     def execute(self):
         """Execute the user function (dummy method)."""
 
         raise RelaxImplementError
 
@@ -684,7 +684,7 @@
 
 
     def ok(self, event):
         """Accept the user function.
 
         @param event:   The wx event.
         @type event:    wx event
@@ -698,7 +698,7 @@
 
 
     def setup_frame(self):
-        """Set up the generic user function frame.
+        """Set up the generic frame.
 
         @return:    The sizer object.
         @rtype:     wx.Sizer instance
@@ -278,13 +278,13 @@
 
     def apply(self, event):
-        """Apply the user function.
+        """Apply the operation.
 
         @param event:   The wx event.
@@ -330,7 +330,7 @@
 
     def cancel(self, event):
-        """Cancel the user function.
+        """Cancel the operation.
 
         @param event:   The wx event.
@@ -450,7 +450,7 @@
 
     def execute(self):
-        """Execute the user function (dummy method)."""
+        """Execute the operation (dummy method)."""
 
         raise RelaxImplementError
@@ -684,7 +684,7 @@
 
     def ok(self, event):
-        """Accept the user function.
+        """Accept the operation.
 
         @param event:   The wx event.




Related Messages


Powered by MHonArc, Updated Thu Jun 16 17:20:02 2011